@@ -2,12 +2,13 @@
 
 namespace Tests\Nyholm\Psr7\Integration;
 
+use Psr\Http\Message\ResponseInterface;
 use Http\Psr7Test\ResponseIntegrationTest;
 use Nyholm\Psr7\Response;
 
 class ResponseTest extends ResponseIntegrationTest
 {
-    public function createSubject()
+    public function createSubject(): ResponseInterface
     {
         return new Response();
     }
